diff --git a/llama-index-core/llama_index/core/storage/kvstore/postgres_kvstore.py b/llama-index-core/llama_index/core/storage/kvstore/postgres_kvstore.py
index 4402d7c0b45c50b50bbaf6fa8ebfc78365fd46a9..966e26df420733ef348128fe0cf9642cdaaede80 100644
--- a/llama-index-core/llama_index/core/storage/kvstore/postgres_kvstore.py
+++ b/llama-index-core/llama_index/core/storage/kvstore/postgres_kvstore.py
@@ -55,11 +55,13 @@ class PostgresKVStore(BaseKVStore):
     """Postgres Key-Value store.
 
     Args:
-        mongo_client (Any): MongoDB client
-        uri (Optional[str]): MongoDB URI
-        host (Optional[str]): MongoDB host
-        port (Optional[int]): MongoDB port
-        db_name (Optional[str]): MongoDB database name
+        connection_string (str): psycopg2 connection string
+        async_connection_string (str): asyncpg connection string
+        table_name (str): table name
+        schema_name (Optional[str]): schema name
+        perform_setup (Optional[bool]): perform table setup
+        debug (Optional[bool]): debug mode
+        use_jsonb (Optional[bool]): use JSONB data type for storage
     """
 
     connection_string: str
diff --git a/llama-index-integrations/storage/kvstore/llama-index-storage-kvstore-postgres/llama_index/storage/kvstore/postgres/base.py b/llama-index-integrations/storage/kvstore/llama-index-storage-kvstore-postgres/llama_index/storage/kvstore/postgres/base.py
index 4402d7c0b45c50b50bbaf6fa8ebfc78365fd46a9..966e26df420733ef348128fe0cf9642cdaaede80 100644
--- a/llama-index-integrations/storage/kvstore/llama-index-storage-kvstore-postgres/llama_index/storage/kvstore/postgres/base.py
+++ b/llama-index-integrations/storage/kvstore/llama-index-storage-kvstore-postgres/llama_index/storage/kvstore/postgres/base.py
@@ -55,11 +55,13 @@ class PostgresKVStore(BaseKVStore):
     """Postgres Key-Value store.
 
     Args:
-        mongo_client (Any): MongoDB client
-        uri (Optional[str]): MongoDB URI
-        host (Optional[str]): MongoDB host
-        port (Optional[int]): MongoDB port
-        db_name (Optional[str]): MongoDB database name
+        connection_string (str): psycopg2 connection string
+        async_connection_string (str): asyncpg connection string
+        table_name (str): table name
+        schema_name (Optional[str]): schema name
+        perform_setup (Optional[bool]): perform table setup
+        debug (Optional[bool]): debug mode
+        use_jsonb (Optional[bool]): use JSONB data type for storage
     """
 
     connection_string: str
diff --git a/llama-index-core/llama_index/core/storage/docstore/postgres_docstore.py b/llama-index-core/llama_index/core/storage/docstore/postgres_docstore.py
index 6cc796497323b6577a45d44c22a2189b493df2dc..f29a87faf9d7128389d25491635bafaca669a28a 100644
--- a/llama-index-core/llama_index/core/storage/docstore/postgres_docstore.py
+++ b/llama-index-core/llama_index/core/storage/docstore/postgres_docstore.py
@@ -6,13 +6,14 @@ from llama_index.core.storage.kvstore.postgres_kvstore import PostgresKVStore
 
 
 class PostgresDocumentStore(KVDocumentStore):
     """Mongo Document (Node) store.
 
-    A MongoDB store for Document and Node objects.
+    A Postgres store for Document and Node objects.
 
     Args:
-        mongo_kvstore (MongoDBKVStore): MongoDB key-value store
+        postgres_kvstore (PostgresKVStore): Postgres key-value store
         namespace (str): namespace for the docstore
+        batch_size (int): batch size for bulk operations
 
     """
 
@@ -6,13 +6,14 @@ from llama_index.core.storage.kvstore.postgres_kvstore import PostgresKVStore
 
 class PostgresDocumentStore(KVDocumentStore):
-    """Mongo Document (Node) store.
+    """Postgres Document (Node) store.
 
diff --git a/llama-index-integrations/storage/docstore/llama-index-storage-docstore-postgres/llama_index/storage/docstore/postgres/base.py b/llama-index-integrations/storage/docstore/llama-index-storage-docstore-postgres/llama_index/storage/docstore/postgres/base.py
index b9b9ae38cb1113970c6038e79c776ca89806d9b0..abb45da70327ac5e8e2fc28a10d1492504353e74 100644
--- a/llama-index-integrations/storage/docstore/llama-index-storage-docstore-postgres/llama_index/storage/docstore/postgres/base.py
+++ b/llama-index-integrations/storage/docstore/llama-index-storage-docstore-postgres/llama_index/storage/docstore/postgres/base.py
@@ -6,13 +6,14 @@ from llama_index.storage.kvstore.postgres import PostgresKVStore
 
 
 class PostgresDocumentStore(KVDocumentStore):
     """Mongo Document (Node) store.
 
-    A MongoDB store for Document and Node objects.
+    A Postgres store for Document and Node objects.
 
     Args:
-        mongo_kvstore (MongoDBKVStore): MongoDB key-value store
+        postgres_kvstore (PostgresKVStore): Postgres key-value store
         namespace (str): namespace for the docstore
+        batch_size (int): batch size for bulk operations
 
     """
 
@@ -6,13 +6,14 @@ from llama_index.storage.kvstore.postgres import PostgresKVStore
 
 class PostgresDocumentStore(KVDocumentStore):
-    """Mongo Document (Node) store.
+    """Postgres Document (Node) store.
 